/*
 * Copyright (c) 2015 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef _AIR_MEDIAHUB_DATAMGR_H__
#define _AIR_MEDIAHUB_DATAMGR_H__

#include "data/mediadata.h"
#include "data/albumdata.h"
#include "data/folderdata.h"

#define MOVIE_MEDIA_COND "media_type=1 AND copyright!=\"Unknown\""
#define GALLERY_MEDIA_COND "(media_type=0 OR (media_type=1 AND copyright=\"Unknown\"))"
#define MUSIC_MEDIA_COND "media_type=3"

enum data_type {
	E_DATA_MEDIA = 0,
	E_DATA_ALBUM,
	E_DATA_FOLDER,
	E_DATA_MAX
};

enum source_type {
	E_SOURCE_INTERNAL = MEDIA_CONTENT_STORAGE_INTERNAL,
	E_SOURCE_EXTERNAL = MEDIA_CONTENT_STORAGE_EXTERNAL_USB,
	E_SOURCE_ALL
};

struct data_ops {
	void *(*create)(const char *media_type, int source_type);
	void (*destroy)(void *handle);
	Eina_List *(*get_list)(void *handle, int type, void *data);
	Eina_List *(*get_group)(void *handle, int type, void *data);
	void (*free_group)(Eina_List *list);
	int (*get_count)(void *handle, int type);
	void (*set_source)(void *handle, int source_type);
};

struct datamgr {
	void *handle;
	struct data_ops *ops;
};

struct group_info {
	char *name;
	Eina_List *list;
	void *data;
};

struct datamgr *datamgr_create(int data_type, const char *media_type,
			int source_type);
void datamgr_destroy(struct datamgr *dmgr);

#endif /* _AIR_MEDIAHUB_DATAMGR_H__ */
